#!/usr/bin/python                                                                                                                                             
#-*- coding: utf-8 -*-

__all__ = ['Identify', 'Setup', 'annotate_file']